==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/GetRunResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetRunResponse(
    run: Option[zio.aws.devicefarm.model.Run] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.GetRunResponse = {
    import GetRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.GetRunResponse
      .builder()
      .optionallyWith(run.map(value => value.buildAwsValue()))(_.run)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.GetRunResponse.ReadOnly =
    zio.aws.devicefarm.model.GetRunResponse.wrap(buildAwsValue())
}
object GetRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.GetRunResponse =
      zio.aws.devicefarm.model
        .GetRunResponse(run.map(value => value.asEditable))
    def run: Option[zio.aws.devicefarm.model.Run.ReadOnly]
    def getRun: ZIO[Any, AwsError, zio.aws.devicefarm.model.Run.ReadOnly] =
      AwsError.unwrapOptionField("run", run)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ) extends zio.aws.devicefarm.model.GetRunResponse.ReadOnly {
    override val run: Option[zio.aws.devicefarm.model.Run.ReadOnly] = scala
      .Option(impl.run())
      .map(value => zio.aws.devicefarm.model.Run.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ): zio.aws.devicefarm.model.GetRunResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-devicefarm_3-6.20.74.2-sources.jar: zio/aws/devicefarm/model/GetRunResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetRunResponse(
    run: Optional[zio.aws.devicefarm.model.Run] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.GetRunResponse = {
    import GetRunResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.GetRunResponse
      .builder()
      .optionallyWith(run.map(value => value.buildAwsValue()))(_.run)
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.GetRunResponse.ReadOnly =
    zio.aws.devicefarm.model.GetRunResponse.wrap(buildAwsValue())
}
object GetRunResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.GetRunResponse =
      zio.aws.devicefarm.model
        .GetRunResponse(run.map(value => value.asEditable))
    def run: Optional[zio.aws.devicefarm.model.Run.ReadOnly]
    def getRun: ZIO[Any, AwsError, zio.aws.devicefarm.model.Run.ReadOnly] =
      AwsError.unwrapOptionField("run", run)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ) extends zio.aws.devicefarm.model.GetRunResponse.ReadOnly {
    override val run: Optional[zio.aws.devicefarm.model.Run.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.run())
        .map(value => zio.aws.devicefarm.model.Run.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.GetRunResponse
  ): zio.aws.devicefarm.model.GetRunResponse.ReadOnly = new Wrapper(impl)
}
